@@ -20,6 +20,7 @@
     incomplete_features,
     indirect_structural_match,
     inline_no_sanitize,
+    invalid_codeblock_attribute,
     invalid_type_param_default,
     invalid_value,
     irrefutable_let_patterns,
@@ -28,6 +29,7 @@
     macro_expanded_macro_exports_accessed_by_absolute_paths,
     meta_variable_misuse,
     missing_copy_implementations,
+    missing_crate_level_docs,
     missing_docs,
     missing_fragment_specifier,
     mutable_borrow_reservation_conflict,
@@ -71,6 +73,7 @@
     unused_allocation,
     unused_assignments,
     unused_attributes,
+    unused_braces,
     unused_comparisons,
     unused_doc_comments,
     unused_extern_crates,
